utils.specutils package
=======================

avoidregion
----------------------------------
.. automodule:: utils.specutils.avoidregion
    :members:
    :undoc-members:
    :show-inheritance:
    :noindex:

calc_covering_fraction
---------------------------------------------

.. automodule:: utils.specutils.calc_covering_fraction
    :members:
    :undoc-members:
    :show-inheritance:
    :noindex:

calc_plot_metrics
----------------------------------------

.. automodule:: utils.specutils.calc_plot_metrics
    :members:
    :undoc-members:
    :show-inheritance:
    :noindex:

debug_oplot
----------------------------------

.. automodule:: utils.specutils.debug_oplot
    :members:
    :undoc-members:
    :show-inheritance:
    :noindex:

dq_has_flag
----------------------------------

.. automodule:: utils.specutils.dq_has_flag
    :members:
    :undoc-members:
    :show-inheritance:
    :noindex:

edge_trim
--------------------------------

.. automodule:: utils.specutils.edge_trim
    :members:
    :undoc-members:
    :show-inheritance:
    :noindex:

get_flux_stats
-------------------------------------

.. automodule:: utils.specutils.get_flux_stats
    :members:
    :undoc-members:
    :show-inheritance:
    :noindex:

is_bad_dq
--------------------------------

.. automodule:: utils.specutils.is_bad_dq
    :members:
    :undoc-members:
    :show-inheritance:
    :noindex:

rms
--------------------------

.. automodule:: utils.specutils.rms
    :members:
    :undoc-members:
    :show-inheritance:
    :noindex:

set_plot_xrange
--------------------------------------

.. automodule:: utils.specutils.set_plot_xrange
    :members:
    :undoc-members:
    :show-inheritance:
    :noindex:

set_plot_yrange
--------------------------------------

.. automodule:: utils.specutils.set_plot_yrange
    :members:
    :undoc-members:
    :show-inheritance:
    :noindex:

specutilserror
-------------------------------------

.. automodule:: utils.specutils.specutilserror
    :members:
    :undoc-members:
    :show-inheritance:
    :noindex:

stitch_components
----------------------------------------

.. automodule:: utils.specutils.stitch_components
    :members:
    :undoc-members:
    :show-inheritance:
    :noindex:
